@@ -1,16 +1,15 @@
 import os
 from dask.diagnostics import ProgressBar
-from osgeo import osr
-from osgeo import gdal
-import gzip
-import rasterio
-import zipfile
 import numpy as np
-from scipy.interpolate import NearestNDInterpolator, LinearNDInterpolator
 from pywapor.general.logger import log
 import xarray as xr
-import pandas as pd
-import dask
+from scipy.interpolate import griddata
+import numpy as np
+from scipy.spatial import cKDTree
+from scipy.interpolate.interpnd import _ndim_coords_from_arrays
+import shutil
+import glob
+import rasterio.warp
 
 def process_ds(ds, coords, variables, crs = None):
 
@@ -79,6 +78,68 @@ def open_ds(fp, decode_coords = "all", chunks = "auto"):
     ds = xr.open_dataset(fp, decode_coords = decode_coords, chunks = chunks)
     return ds
 
+def create_wkt(latlim, lonlim):
+    left = lonlim[0]
+    bottom = latlim[0]
+    right = lonlim[1]
+    top = latlim[1]
+    x = f"{left} {bottom},{right} {bottom},{right} {top},{right} {bottom},{left} {bottom}"
+    return "GEOMETRYCOLLECTION(POLYGON((" + x + ")))"
+
+def unpack(file, folder):
+    fn = os.path.splitext(file)[0]
+    shutil.unpack_archive(os.path.join(folder, file), folder)
+    folder = [x for x in glob.glob(os.path.join(folder, fn + "*")) if os.path.isdir(x)][0]
+    return folder
+
+def transform_bb(src_crs, dst_crs, bb):
+    bb =rasterio.warp.transform_bounds(src_crs, dst_crs, *bb, densify_pts=21)
+    return bb
+
+# def regrid_curvilinear(ds, resolution):
+
+#     # Define new grid.
+#     xmin = ds.x.min().values
+#     xmax = ds.x.max().values
+#     ymin = ds.y.min().values
+#     ymax = ds.y.max().values
+#     dx = dy = resolution
+#     gridx = np.arange(xmin, xmax + dx, dx)
+#     gridy = np.arange(ymin, ymax + dy, dy)
+#     mgridx, mgridy = np.meshgrid(gridx, gridy)
+
+#     out_ds = xr.Dataset(None, coords = {"y": gridy, "x": gridx})
+
+#     for var in ds.data_vars:
+
+#         values = ds[var].values.ravel()
+
+#         # Remove no-data pixels.
+#         y = ds.y.values.ravel()[np.isfinite(values)]
+#         x = ds.x.values.ravel()[np.isfinite(values)]
+#         values = values[np.isfinite(values)]
+#         points = np.dstack((x,y))[0]
+
+#         # Calculate pixel distances to points.
+#         tree = cKDTree(points)
+#         xi = _ndim_coords_from_arrays((mgridx, mgridy))
+#         dists = tree.query(xi)[0]
+
+#         # Interpolate points to grid.
+#         grid_z0 = griddata(points, values, (mgridx, mgridy), method = "linear")
+        
+#         # Mask pixels too far away from any point.
+#         grid_z0[dists > dx] = np.nan
+
+#         # Wrap output into xr.Dataset.
+#         out_ds[var] = xr.DataArray(grid_z0, coords = out_ds.coords)
+
+#     out_ds = out_ds.rio.write_crs("epsg:4326")
+
+#     out_ds = out_ds.sortby(out_ds.y, ascending=False)
+
+#     return out_ds
+
 # def ds_remove_except(ds, keep_vars):
 #     """Remove all variables from a dataset except the variables specified with
 #     `keep_vars`. Variables that are coordinates are never removed.
