@@ -120,18 +120,18 @@ if __name__ == "__main__":
 
 #     import pywapor
 
-#     folder = r"/Users/hmcoerver/pywapor_notebooks_b"
-#     latlim = [28.9, 29.7]
-#     lonlim = [30.2, 31.2]
-#     timelim = ["2021-07-01", "2021-07-11"]
-#     composite_length = "DEKAD"
+    folder = r"/Users/hmcoerver/On My Mac/test"
+    latlim = [28.9, 29.7]
+    lonlim = [30.2, 31.2]
+    timelim = ["2021-07-01", "2021-07-11"]
+    composite_length = "DEKAD"
 
 #     et_look_version = "v2"
 #     export_vars = "default"
 
 #     level = "level_1"
 
-#     et_look_sources = pywapor.general.levels.pre_et_look_levels(level)
+    # et_look_sources = pywapor.general.levels.pre_et_look_levels(level)
 
 #     et_look_sources = {k: v for k, v in et_look_sources.items() if k in ["ndvi", "z"]}
 
@@ -165,10 +165,9 @@ if __name__ == "__main__":
     #     {'source': partial(pywapor.se_root.se_root, sources = se_root_sources),
     #         'product_name': 'v2',
     #         'enhancers': 'default'},]
+    import pywapor
 
-    # ds = pywapor.pre_et_look.main(folder, latlim, lonlim, timelim, 
-    #                                 sources = et_look_sources,
-    #                                 bin_length = composite_length)
+    ds = pywapor.pre_et_look.main(folder, latlim, lonlim, timelim)
 
 
 
